==> lxqt-config-2.3.0.tar.xz: lxqt-config-2.3.0/lxqt-config-locale/translations/lxqt-config-locale_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>Ki&amp;tundu:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>Ent&amp;eekateeka enzijjuvu</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>Empandika y&apos;en&amp;namba:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>Empandika ya &amp;budde:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>Empandika ya &amp;ssente:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>Bi&amp;pimo:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>En&amp;gobereragana n&apos;okusengeka:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation>Eby&apos;okulabirako</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>Miwendo:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>Budde:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="289"/>
        <source>Currency:</source>
        <translation>Ssente:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="309"/>
        <source>Measurement Units:</source>
        <translation>Bipimo:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="164"/>
        <source>Unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="226"/>
        <source>Current: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="370"/>
        <source>Format Settings Changed</source>
        <translation>Entereeza zikyusidwa</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="371"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Oyagala okukaza by&apos;okyusizza? Enkyukakyuka zijja okulabika lw&apos;on&apos;oddamu okutandika olutuula.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="518"/>
        <source>Imperial UK</source>
        <translation>Bungereza eby&apos;edda</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="522"/>
        <source>Imperial US</source>
        <translation>US</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="526"/>
        <source>Metric</source>
        <translation>Metiriki</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>LXQt Locale Configuration</source>
        <translation>Enteekateeka za Lokale mu LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Locale Settings</source>
        <translation>Enteekateeka za lokale</translation>
    </message>
</context>
</TS>

==> lxqt-config-2.3.1.tar.xz: lxqt-config-2.3.1/lxqt-config-locale/translations/lxqt-config-locale_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>Ki&amp;tundu:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>Ent&amp;eekateeka enzijjuvu</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>Empandika y&apos;en&amp;namba:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>Empandika ya &amp;budde:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>Empandika ya &amp;ssente:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>Bi&amp;pimo:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>En&amp;gobereragana n&apos;okusengeka:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation>Eby&apos;okulabirako</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>Miwendo:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>Budde:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="289"/>
        <source>Currency:</source>
        <translation>Ssente:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="309"/>
        <source>Measurement Units:</source>
        <translation>Bipimo:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="164"/>
        <source>Unset</source>
        <translation>Ssi kiteekateeke</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="226"/>
        <source>Current: </source>
        <translation>Kaakano: </translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="370"/>
        <source>Format Settings Changed</source>
        <translation>Entereeza zikyusidwa</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="371"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Oyagala okukaza by&apos;okyusizza? Enkyukakyuka zijja okulabika lw&apos;on&apos;oddamu okutandika olutuula.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="518"/>
        <source>Imperial UK</source>
        <translation>Bungereza eby&apos;edda</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="522"/>
        <source>Imperial US</source>
        <translation>US</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="526"/>
        <source>Metric</source>
        <translation>Metiriki</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>LXQt Locale Configuration</source>
        <translation>Enteekateeka za Lokale mu LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Locale Settings</source>
        <translation>Enteekateeka za lokale</translation>
    </message>
</context>
</TS>
